@@ -780,14 +780,14 @@ EAction.prototype.setCursor = function(cursor, name) {
     if (!isNull(di)) {
         di.setCursor(cursor);
     }
-    if (!isNull(name)) {
-        var views = this.getGraphicsViews();
-        for (var i=0; i<views.length; i++) {
-            if (isFunction(views[i].setProperty)) {
-                views[i].setProperty("CursorName", name);
-            }
-        }
-    }
+//    if (!isNull(name)) {
+//        var views = this.getGraphicsViews();
+//        for (var i=0; i<views.length; i++) {
+//            if (isFunction(views[i].setProperty)) {
+//                views[i].setProperty("CursorName", name);
+//            }
+//        }
+//    }
 };
 
 /**
@@ -2063,7 +2063,7 @@ EAction.getEntityIdsUnderCursor = function(di, event, range, selectable) {
  * \return Entity ID under the mouse cursor. User may choose between multiple candidates if
  * result is ambiguous and Alt key is pressed.
  *
- * \param event RRInputEvent
+ * \param event RInputEvent
  * \param preview for previewing purposes
  * \param selectable Only return selectable (editable) entities
  */
@@ -2092,7 +2092,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
     }
 
     var altPressed = isAltPressed(event);
-    if (!altPressed || preview) {
+    if (!altPressed || preview || RSettings.getBoolValue("GraphicsView/DisableAltPicking", false)===true) {
         if (!isNull(action.idFromContextMenu)) {
             // user already chose an entity from the context menu:
             return action.idFromContextMenu;
@@ -2211,6 +2211,10 @@ EAction.warnNotLine = function() {
     EAction.handleUserWarning(qsTr("Entity is not a line."));
 };
 
+EAction.warnNotArc = function() {
+    EAction.handleUserWarning(qsTr("Entity is not an arc."));
+};
+
 EAction.warnNotArcCircle = function() {
     EAction.handleUserWarning(qsTr("Entity is not an arc or circle."));
 };
